# Configuring SSO with Active Directory Federation Services
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services#prerequisites)
  * [Configuring SSO](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services#configuring-sso)
  * [Configuring Attribute Mapping](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services#configuring-attribute-mapping)


Instructions for configuring single sign-on (SSO) with Active Directory Federation Services (AD FS) as an identity provider.
